@@ -102,6 +102,9 @@ sub parse {
     my $self = shift;
     my $text = shift;
 
+    # First join lines splited in multiple lines
+    $text =~ s/\^\r\n//msg;
+
     if ( $text =~ $self->grammar ) {
         return \%/;
     }
